@@ -15,12 +15,6 @@ typedef struct {
 void daemonize(void);
 int addinterfaces(const char *dirname, const int running);
 void debugtimestamp(void);
-uid_t getuser(const char *user);
-gid_t getgroup(const char *group);
-void setuser(const char *user);
-void setgroup(const char *group);
-int direxists(const char *dir);
-int mkpath(const char *dir, const mode_t mode);
 
 void initdstate(DSTATE *s);
 void preparedatabases(DSTATE *s);
@@ -35,7 +29,5 @@ int datalist_timevalidation(DSTATE *s);
 int datalist_writedb(DSTATE *s);
 void handleintsignals(DSTATE *s);
 void preparedirs(DSTATE *s);
-void preparevnstatdir(const char *dir, const char *user, const char *group);
-void updatedirowner(const char *dir, const char *user, const char *group);
 
 #endif
