@@ -1,5 +1,5 @@
 /*
-vnStat daemon - Copyright (c) 2008-2015 Teemu Toivola <tst@iki.fi>
+vnStat daemon - Copyright (c) 2008-2016 Teemu Toivola <tst@iki.fi>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@ vnStat daemon - Copyright (c) 2008-2015 Teemu Toivola <tst@iki.fi>
 #include "dbcache.h"
 #include "cfg.h"
 #include "ibw.h"
+#include "id.h"
 #include "daemon.h"
 #include "vnstatd.h"
 
@@ -158,6 +159,8 @@ int main(int argc, char *argv[])
 	}
 
 	s.running = 1;
+	snprintf(errorstring, 512, "vnStat daemon %s started. (pid:%d uid:%d gid:%d)", getversion(), (int)getpid(), (int)getuid(), (int)getgid());
+	printe(PT_Info);
 
 	/* main loop */
 	while (s.running) {
